@@ -1,6 +1,7 @@
 package Acme::MetaSyntactic::digits;
+use strict;
 use Acme::MetaSyntactic::Locale;
-our @ISA = ( Acme::MetaSyntactic::Locale );
+our @ISA = qw( Acme::MetaSyntactic::Locale );
 __PACKAGE__->init();
 1;
 
